@@ -1,9 +1,11 @@
 use clap::Subcommand;
 
+mod bootstrap;
 mod config;
 mod git_pre_commit;
 mod github_action;
 mod task_docs;
+mod task_stubs;
 
 /// [experimental] Generate files for various tools/services
 #[derive(Debug, clap::Args)]
@@ -15,19 +17,23 @@ pub struct Generate {
 
 #[derive(Debug, Subcommand)]
 enum Commands {
+    Bootstrap(bootstrap::Bootstrap),
     Config(config::Config),
     GitPreCommit(git_pre_commit::GitPreCommit),
     GithubAction(github_action::GithubAction),
     TaskDocs(task_docs::TaskDocs),
+    TaskStubs(task_stubs::TaskStubs),
 }
 
 impl Commands {
     pub fn run(self) -> eyre::Result<()> {
         match self {
+            Self::Bootstrap(cmd) => cmd.run(),
             Self::Config(cmd) => cmd.run(),
             Self::GitPreCommit(cmd) => cmd.run(),
             Self::GithubAction(cmd) => cmd.run(),
             Self::TaskDocs(cmd) => cmd.run(),
+            Self::TaskStubs(cmd) => cmd.run(),
         }
     }
 }
